{{ plugin_card('Device Blinder', 'Privacy in Collobarative Multisig.', url_for('static', filename='img/ghost_3d.png'), "https://github.com/mflaxman/blind-xpub") }}
{{ plugin_card('Joinmarket Frontend', 'Joinmarket Frontend', "https://raw.githubusercontent.com/cryptoadvance/specterext-jmf/e245825e909dd1d567cb4b427670d4e7018ca2c2/images/logo.svg" , "https://github.com/cryptoadvance/specterext-jmf") }}
{{ plugin_card('Cashu', 'Chaumian Ecash wallet', url_for('static', filename='img/ghost.png') , "https://github.com/callebtc/cashu") }}
{{ plugin_card('Something missing?', 'Add to the wishlist', url_for('static', filename='img/ghost.png'), "https://github.com/cryptoadvance/specter-desktop/edit/master/src/cryptoadvance/specter/templates/services/components/wishlist.jinja") }}

